#
# spec file for package ghc-concurrent-output
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name concurrent-output
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        1.10.21
Release:        1.6
Summary:        Ungarble output from several threads or commands
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-ansi-terminal-prof
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-terminal-size-devel
BuildRequires:  ghc-terminal-size-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
ExcludeArch:    %{ix86}

%description
Lets multiple threads and external processes concurrently output to the
console, without it getting all garbled up.

Built on top of that is a way of defining multiple output regions, which are
automatically laid out on the screen and can be individually updated by
concurrent threads. Can be used for progress displays etc.

<<https://joeyh.name/code/concurrent-output/demo2.gif>>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG TODO

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Mon Apr 29 2024 Peter Simons <psimons@suse.com>
- Update concurrent-output to version 1.10.21.
  concurrent-output (1.10.21) unstable; urgency=medium
  * Allow ansi-terminal-1.1
  - - Joey Hess <id@joeyh.name>  Mon, 29 Apr 2024 10:15:55 -0400
* Thu Oct 12 2023 Peter Simons <psimons@suse.com>
- Update concurrent-output to version 1.10.20.
  concurrent-output (1.10.20) unstable; urgency=medium
  * Allow text-2.1.
  - - Joey Hess <id@joeyh.name>  Thu, 12 Oct 2023 15:46:36 -0400
* Wed Aug 30 2023 Peter Simons <psimons@suse.com>
- Update concurrent-output to version 1.10.19.
  concurrent-output (1.10.19) unstable; urgency=medium
  * Support building for WASM.
  - - Joey Hess <id@joeyh.name>  Wed, 30 Aug 2023 16:03:03 -0400
* Mon May 15 2023 Peter Simons <psimons@suse.com>
- Update concurrent-output to version 1.10.18.
  concurrent-output (1.10.18) unstable; urgency=medium
  * Avoid some build warnings on Windows.
  * Allow ansi-terminal-1.0
  - - Joey Hess <id@joeyh.name>  Mon, 15 May 2023 16:32:50 -0400
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Jan 10 2023 Peter Simons <psimons@suse.com>
- Update concurrent-output to version 1.10.17.
  concurrent-output (1.10.17) unstable; urgency=medium
  * Fix ansi-terminal dependency to only include >= 0.6.2,
    which is needed for hSupportsANSI.
  - - Joey Hess <id@joeyh.name>  Tue, 10 Jan 2023 15:40:11 -0400
* Fri May 20 2022 Peter Simons <psimons@suse.com>
- Update concurrent-output to version 1.10.16.
  concurrent-output (1.10.16) unstable; urgency=medium
  * Allow transformers-0.6
    (Thanks, Janus Troelsen)
  - - Joey Hess <id@joeyh.name>  Fri, 20 May 2022 19:31:56 -0400
* Fri Feb  4 2022 Peter Simons <psimons@suse.com>
- Update concurrent-output to version 1.10.15.
  concurrent-output (1.10.15) unstable; urgency=medium
  * Allow text-2.0
  - - Joey Hess <id@joeyh.name>  Fri, 04 Feb 2022 15:32:58 -0400
  concurrent-output (1.10.14) unstable; urgency=medium
  * Allow ansi-terminal-0.11.1.
  - - Joey Hess <id@joeyh.name>  Wed, 24 Nov 2021 09:18:20 -0400
  concurrent-output (1.10.13) unstable; urgency=medium
  * outputConcurrent and errorConcurrent are now safe to call from a thread
    that receives async exceptions.
  * Fix compilation with GHC head.
    (Thanks, Ellie Hermaszewska)
  - - Joey Hess <id@joeyh.name>  Mon, 22 Nov 2021 11:19:21 -0400
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Thu Jun 11 2020 psimons@suse.com
- Update concurrent-output to version 1.10.12.
  concurrent-output (1.10.12) unstable; urgency=medium
  * Bugfix: createProcessConcurrent would sometimes send the process's
    output to the console when it was supposed to be piped to a handle.
    (1.7.5 introduced this bug)
  * System.Console.Regions should be safe to use in a thread that
    receives async exceptions; displayConsoleRegions and withConsoleRegion
    have been made async exception safe.
    (However, System.Console.Concurrent is not async exception safe.)
  * Improve documentation about when withConcurrentOutput should be used.
  * Remove some unused code.
  * Allow building with older ansi-terminal versions, not only 0.9+.
  - - Joey Hess <id@joeyh.name>  Wed, 10 Jun 2020 17:22:39 -0400
* Tue Jun  9 2020 psimons@suse.com
- Add concurrent-output at version 1.10.11.
